@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactiondeleteheader.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -40,11 +27,11 @@ SieveActionDeleteHeader::SieveActionDeleteHeader(SieveEditorGraphicalModeWidget
 QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
-    SelectMatchTypeComboBox *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchType->setObjectName(QStringLiteral("matchtype"));
     connect(matchType, &SelectMatchTypeComboBox::valueChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(matchType, 0, 0);
@@ -52,7 +39,7 @@ QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
     QLabel *lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 1);
 
-    QLineEdit *headerEdit = new QLineEdit;
+    auto *headerEdit = new QLineEdit;
     headerEdit->setObjectName(QStringLiteral("headeredit"));
     connect(headerEdit, &QLineEdit::textChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(headerEdit, 0, 2);
@@ -60,14 +47,14 @@ QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("value:"));
     grid->addWidget(lab, 1, 1);
 
-    QLineEdit *valueEdit = new QLineEdit;
+    auto *valueEdit = new QLineEdit;
     valueEdit->setObjectName(QStringLiteral("valueedit"));
     connect(valueEdit, &QLineEdit::textChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(valueEdit, 1, 2);
     return w;
 }
 
-bool SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w, QString &error, bool isNegative)
+void SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w, QString &error, bool isNegative)
 {
     int index = 0;
     while (element.readNextStartElement()) {
@@ -78,21 +65,21 @@ bool SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w,
                 nameValue = element.attributes().value(QLatin1String("name")).toString();
             }
             const bool isNegative = (nameValue == QLatin1String("not"));
-            bool result = parseValue(element, w, error, isNegative);
+            parseValue(element, w, error, isNegative);
             element.skipCurrentElement();
-            return result;
+            return;
         } else if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             combo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), isNegative), name(), error);
         } else if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
+                auto *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
                 edit->setText(element.readElementText());
             } else if (index == 1) {
-                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
+                auto *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
                 value->setText(element.readElementText());
             } else {
-                tooManyArgument(tagName, index, 2, error);
+                tooManyArguments(tagName, index, 2, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionAddHeader::setParamWidgetValue too many argument :" << index;
             }
             ++index;
@@ -107,13 +94,11 @@ bool SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w,
             qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
         }
     }
-
-    return true;
 }
 
-bool SieveActionDeleteHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionDeleteHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    return parseValue(element, w, error, false);
+    parseValue(element, w, error, false);
 }
 
 QString SieveActionDeleteHeader::code(QWidget *w) const
